<?php
namespace Aws\ApplicationAutoScaling\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Application Auto Scaling** service.
 */
class ApplicationAutoScalingException extends AwsException {}
